Derive Macro docbot_derive::Docbot
source · [−]#[derive(Docbot)]
{
// Attributes available to this derive:
#[docbot]
}
Construct a new command or set of commands from doc comments
#[derive(Docbot)]
{
// Attributes available to this derive:
#[docbot]
}
Construct a new command or set of commands from doc comments